@@ -1,8 +1,14 @@
 from typing import Optional, Union
 
-from nonebot.adapters.onebot.v11 import Bot, Event, Message, MessageSegment, escape
+from nonebot.adapters.onebot.v11 import Bot, Event, Message, MessageSegment
 from nonebot.log import logger
 
+from .models import (ChannelCreatedNoticeEvent, ChannelDestroyedNoticeEvent,
+                     ChannelNoticeEvent, ChannelUpdatedNoticeEvent,
+                     GuildChannelRecallNoticeEvent, GuildMessageEvent,
+                     MessageReactionsUpdatedNoticeEvent)
+from .permission import GUILD, GUILD_SUPERUSER
+
 original_send = Bot.send
 
 
@@ -23,9 +29,6 @@ async def patched_send(
     )
 
     user_id: Optional[int] = getattr(event, "user_id", None)
-    message = (
-        escape(message, escape_comma=False) if isinstance(message, str) else message
-    )
 
     message_sent = Message()
     if user_id and kwargs.get("at_sender", False):
@@ -42,4 +45,15 @@ async def patched_send(
 
 Bot.send = patched_send
 
-from .models import *  # noqa
+
+__all__ = [
+    "GUILD",
+    "GUILD_SUPERUSER",
+    "GuildMessageEvent",
+    "ChannelNoticeEvent",
+    "GuildChannelRecallNoticeEvent",
+    "MessageReactionsUpdatedNoticeEvent",
+    "ChannelUpdatedNoticeEvent",
+    "ChannelCreatedNoticeEvent",
+    "ChannelDestroyedNoticeEvent",
+]
